{% extends "_base.html" %}

{% block home %} 
 <li class="active"><a href="/">Home</a></li>    
{% endblock %}

{% block body %}

<div class="jumbotron">
    <div class="container">
        <div class="row">
            <div class="col-md-7">
                <h1>{{this.title}}</h1>
                {{this.body}}
             </div>
        </div>
    </div>
</div>

{% endblock %}
