body {
    position: relative;
    padding-top: 50px;
    padding-bottom: 20px;
}

.page-header {
     margin-top: 30px;
}

.breadcrumb {
    margin-top: 20px;
}

/* footer */

.footer {
  margin-top: 20px;
  padding-top: 16px;
  color: #777;
  border-top: 1px solid #eee;
}

/* toc */
.toc ul  {
    padding-left: 0;
    list-style: none;
}

.toc ul ul {
    padding-left: 10px;
    font-size: 95%;
}

/* heading scrolling */

h2[id]:before, 
h3[id]:before{
    content: "";
    display: block;
    height: 70px;
    margin-top:-70px;
}

/* affix hacks from boostrap 3.0 docs */
.sidebar.affix {
    position: static;
}

@media (min-width: 992px) {
  /* Widen the fixed sidebar */
  .sidebar.affix,
  .sidebar.affix-bottom {
    width: 213px;
  } 
  .sidebar.affix {
    position: fixed; /* Undo the static from mobile first approach */
    top: 80px;
  }
  .sidebar.affix-bottom {
    position: absolute; /* Undo the static from mobile first approach */
  }
}

@media (min-width: 1200px) {
  /* Widen the fixed sidebar again */
  .sidebar.affix,
  .sidebar.affix-bottom {
    width: 263px;
  }
}


